<template>
	<BasicModal v-bind="$attrs" @register="registerModal" destroyOnClose :title="title" :width="800" @ok="handleSubmit">
		<BasicForm @register="registerForm" />
	</BasicModal>
</template>

<script lang="ts" setup>
import dayjs from 'dayjs';
	import { computed, ref, unref } from 'vue'
	import { saveOrUpdate } from '../../api/DryOrder.api'
	import { formSchema } from '../../dataDefine/DryOrder.data'
	import { BasicForm, useForm } from '/@/components/Form/index'
	import { BasicModal, useModalInner } from '/@/components/Modal'
	// Emits声明
	const emit = defineEmits(['register', 'success'])
	const isUpdate = ref(true)
	//searchFormSchema
	const [registerForm, { setProps, resetFields, setFieldsValue, validate }] = useForm({
		//labelWidth: 150,
		schemas: formSchema,
		showActionButtonGroup: false,
		baseColProps: { span: 24 },
	})
	//表单赋值
	const [registerModal, { setModalProps, closeModal }] = useModalInner(async (data) => {
		//重置表单
		await resetFields()
		setModalProps({ confirmLoading: false, showCancelBtn: !!data?.showFooter, showOkBtn: !!data?.showFooter })
		isUpdate.value = !!data?.isUpdate
		if (unref(isUpdate)) {
			//表单赋值
			await setFieldsValue({
				...data.record,
			})
		} else {
      await setFieldsValue({
        orderTime: dayjs(getDateStr(new Date()), 'YYYY-MM-DD'),
        code: getCodeByDate(new Date()),
        dryer: 1,
        feed: 16,
        orderStatus: 0,
			})
    }
		// 隐藏底部时禁用整个表单
		setProps({ disabled: !data?.showFooter })
	})
	//设置标题
	const title = computed(() => (!unref(isUpdate) ? '新增' : '编辑'))
	//表单提交事件
	async function handleSubmit(v) {
		try {
			let values = await validate()
      values.orderTime = dayjs(values.orderTime).format('YYYY-MM-DD HH:mm:ss')

			setModalProps({ confirmLoading: true })
			//提交表单
			await saveOrUpdate(values, isUpdate.value)
			//关闭弹窗
			closeModal()
			//刷新列表
			emit('success')
		} finally {
			setModalProps({ confirmLoading: false })
		}
	}
  const getCodeByDate = (date) => {
    let year = date.getFullYear()
    let month = date.getMonth() + 1
    let day = date.getDate()
    let hour = date.getHours()
    let minute = date.getMinutes()
    let second = date.getSeconds()
    return `${year}${month}${day}${hour}${minute}${second}`
  }
  const getDateStr = (date) => {
    let year = date.getFullYear()
    let month = date.getMonth() + 1
    let day = date.getDate()
    if (month < 10) {
      month = '0' + month
    }
    if (day < 10) {
      day = '0' + day
    }
    return `${year}-${month}-${day}`
  }
</script>

<style lang="less" scoped>
	/** 时间和数字输入框样式 */
	:deep(.ant-input-number) {
		width: 100%;
	}

	:deep(.ant-calendar-picker) {
		width: 100%;
	}
</style>
